@@ -9,7 +9,6 @@
 #define PRINTERMANAGER_H
 
 #include <KQuickConfigModule>
-#include <QDBusMessage>
 #include <QObject>
 
 namespace PMTypes
@@ -25,6 +24,9 @@ class PrinterManager : public KQuickConfigModule
 {
     Q_OBJECT
 
+    Q_PROPERTY(QString osName READ osName CONSTANT FINAL)
+    Q_PROPERTY(QString osBugReportUrl READ osBugReportUrl CONSTANT FINAL)
+
     Q_PROPERTY(QVariantList remotePrinters READ remotePrinters NOTIFY remotePrintersLoaded)
 
     Q_PROPERTY(QVariantList recommendedDrivers READ recommendedDrivers NOTIFY recommendedDriversLoaded)
@@ -56,6 +58,11 @@ public:
 
     Q_INVOKABLE void pausePrinter(const QString &name);
     Q_INVOKABLE void resumePrinter(const QString &name);
+    Q_INVOKABLE static bool isIPPCapable(const QString &uri);
+    Q_INVOKABLE static bool isSCPAvailable();
+
+    QString osName() const;
+    QString osBugReportUrl() const;
 
     bool shareConnectedPrinters() const;
     bool allowPrintingFromInternet() const;
@@ -78,25 +85,25 @@ Q_SIGNALS:
     void removeDone();
     void saveDone();
     void serverSettingsChanged();
+    void serverStopped();
+    void serverStarted();
     void remotePrintersLoaded();
     void recommendedDriversLoaded();
 
-private Q_SLOTS:
-    void getDriversFinished(const QDBusMessage &message);
-    void getDriversFailed(const QDBusError &error, const QDBusMessage &message);
-
 private:
     KCupsRequest *setupRequest(std::function<void()> finished = []() {});
     QVariantList remotePrinters() const;
     QVariantList recommendedDrivers() const;
     QVariantMap serverSettings() const;
     bool serverSettingsLoaded() const;
-    void serverEvent(const QString &event, bool reload, const QString &msg = QString());
+    void initOSRelease();
 
     QVariantMap m_serverSettings;
     bool m_serverSettingsLoaded = false;
     QVariantList m_remotePrinters;
     QVariantList m_recommendedDrivers;
+    QString m_osName;
+    QString m_osBugReportUrl;
 };
 
 #endif
